import{_ as e}from"./DbInitComponent.vue_vue_type_script_setup_true_lang-q347H4HE.js";import{d as o,c as t,o as a}from"./index-emI0GJfG.js";const m=o({__name:"DbInitView",setup(n){return(r,_)=>(a(),t(e))}});export{m as default};
