import{v as e,E as n}from"./index-emI0GJfG.js";const i=(t="",s=[],o=[])=>e.post("/api/rs/user_list",{word:t,wxids:s,labels:o}).then(r=>r).catch(r=>(console.log(r),"")),l=()=>e.post("/api/rs/user_session_list",{}).then(t=>t).catch(t=>(console.log(t),[])),u=()=>e.get("/api/rs/mywxid").then(t=>t.my_wxid).catch(t=>(console.log(t),"")),p=()=>e.post("/api/ls/realtimemsg",{}).then(t=>(console.log(t),n({title:"Success",message:"获取实时消息成功!",type:"success"}),!0)).catch(t=>(console.log(t),n({title:"Error",message:"获取实时消息失败!",type:"error"}),!1)),a=t=>e.post("/api/rs/msg_count",{wxids:t}).then(s=>s).catch(s=>(console.log(s),"")),g=t=>a([t]).then(s=>s[t]).catch(s=>(console.log(s),0)),h=(t,s,o)=>e.post("/api/rs/msg_list",{start:s,limit:o,wxid:t}).then(r=>r).catch(r=>(console.log(r),""));export{l as a,i as b,p as c,g as d,u as e,h as f};
